//[mahjong-utils](../../../../index.md)/[mahjongutils.hanhu](../../index.md)/[HanHuOptions](../index.md)/[Companion](index.md)/[Default](-default.md)

# Default

[common]\
val [Default](-default.md): [HanHuOptions](../index.md)
